@@ -53,6 +53,7 @@ import org.apache.flink.api.common.state.StateDescriptor;
 import org.apache.flink.api.common.state.ValueState;
 import org.apache.flink.api.common.state.ValueStateDescriptor;
 import org.apache.flink.api.common.typeutils.TypeSerializer;
+import org.apache.flink.api.java.tuple.Tuple2;
 import org.apache.flink.metrics.CharacterFilter;
 import org.apache.flink.metrics.Counter;
 import org.apache.flink.metrics.Gauge;
@@ -73,6 +74,7 @@ import org.apache.flink.statefun.flink.core.StatefulFunctionsUniverse;
 import org.apache.flink.statefun.flink.core.TestUtils;
 import org.apache.flink.statefun.flink.core.backpressure.ThresholdBackPressureValve;
 import org.apache.flink.statefun.flink.core.message.Message;
+import org.apache.flink.statefun.flink.core.message.MessageFactoryKey;
 import org.apache.flink.statefun.flink.core.message.MessageFactoryType;
 import org.apache.flink.streaming.api.operators.InternalTimerService;
 import org.apache.flink.streaming.api.operators.Output;
@@ -91,7 +93,8 @@ public class ReductionsTest {
     Reductions reductions =
         Reductions.create(
             new ThresholdBackPressureValve(-1),
-            new StatefulFunctionsUniverse(MessageFactoryType.WITH_KRYO_PAYLOADS),
+            new StatefulFunctionsUniverse(
+                MessageFactoryKey.forType(MessageFactoryType.WITH_KRYO_PAYLOADS, null)),
             new FakeRuntimeContext(),
             new FakeKeyedStateBackend(),
             new FakeTimerServiceFactory(),
@@ -233,11 +236,6 @@ public class ReductionsTest {
       throw new UnsupportedOperationException();
     }
 
-    @Override
-    public Map<String, Accumulator<?, ?>> getAllAccumulators() {
-      throw new UnsupportedOperationException();
-    }
-
     @Override
     public IntCounter getIntCounter(String name) {
       throw new UnsupportedOperationException();
@@ -299,6 +297,11 @@ public class ReductionsTest {
         AggregatingStateDescriptor<IN, ACC, OUT> stateProperties) {
       throw new UnsupportedOperationException();
     }
+
+    @Override
+    public void registerUserCodeClassLoaderReleaseHookIfAbsent(String s, Runnable runnable) {
+      throw new UnsupportedOperationException();
+    }
   }
 
   private static final class FakeKeyedStateBackend implements KeyedStateBackend<Object> {
@@ -367,6 +370,11 @@ public class ReductionsTest {
     public TypeSerializer<Object> getKeySerializer() {
       throw new UnsupportedOperationException();
     }
+
+    @Override
+    public <N> Stream<Tuple2<Object, N>> getKeysAndNamespaces(String state) {
+      throw new UnsupportedOperationException();
+    }
   }
 
   private static final class FakeTimerServiceFactory implements TimerServiceFactory {
